@@ -40,6 +40,8 @@ OC.L10N.register(
     "Takes a link and adds it to your collection of bookmarks." : "Tekur slóðir og bætir þeim í bókamerkin þín.",
     "Bookmarks Backups" : "Öryggisafrit bókamerkja",
     "Collect and manage bookmarks, synced with all your devices" : "Sýslaðu með og safnaðu bókamerkjum, samstillt við öll tækin þín",
+    "Do you really want to delete this bookmark?" : "Viltu örugglega eyða þessu bókamerki?",
+    "Link copied to clipboard" : "Tengill afritaður á klippispjald",
     "Enter new title" : "Settu inn nýjan titil",
     "Select bookmark" : "Veldu bókamerki",
     "You have never clicked this link" : "Þú hefur aldrei smellt á þennan tengil",
@@ -52,8 +54,6 @@ OC.L10N.register(
     "Put bookmark into trash bin" : "Setja bókamerki í ruslið",
     "Restore bookmark" : "Endurheimta bókamerki",
     "Delete bookmark permanently" : "Eyða bókamerki endanlega",
-    "Do you really want to delete this bookmark?" : "Viltu örugglega eyða þessu bókamerki?",
-    "Link copied to clipboard" : "Tengill afritaður á klippispjald",
     "Content pending" : "Efni sem bíður",
     "This content is being downloaded for offline use. Please check back later." : "Verið er að sækja þetta efni til að geta notað það án nettengingar. Athugaðu aftur síðar.",
     "Bookmarked {time} ago" : "Sett í bókamerki fyrir {time} síðan",
@@ -65,14 +65,23 @@ OC.L10N.register(
     "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bókamerktir tenglar eru yfirfarnir reglulega og þeir sem ekki tekst að rekja eru taldir upp hér.",
     "You can share bookmark folders with others. All folders shared with you are listed here." : "Þú getur deilt bókamerkjamöppu með öðrum. Allar möppur sem deilt er með þér birtast hér.",
     "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Eitt bókamerki getur verið samtímis í mörgum möppum. Sé það uppfært uppfærast öll afrit þess. Öll tvítekin bókamerki eru talin upp hér til hagræðis.",
+    "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
+    "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
+    "Do you really want to delete these items?" : "Ertu viss um að þú viljir eyða þessum atriðum?",
     "Open all selected" : "Opna allt valið",
     "Move selection" : "Færa valið",
     "Edit tags of selection" : "Breyta merkjum í vali",
     "Delete selection" : "Eyða vali",
     "Select all" : "Select all",
     "Cancel selection" : "Hætta við val",
-    "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
-    "Do you really want to delete these items?" : "Ertu viss um að þú viljir eyða þessum atriðum?",
+    "Sort by created date" : "Sort by created date",
+    "Sort by last modified" : "Raða eftir þegar var síðast breytt",
+    "Sort by title" : "Raða eftir titli",
+    "Sort by click count" : "Raða eftir fjölda smella",
+    "Sort by manual order" : "Raða eftir handvirkri röð",
+    "Sort by URL" : "Raða eftir slóð",
+    "RSS feed copied" : "RSS-fréttastreymi afritað",
     "Trash Bin" : "Rusl",
     "Go back" : "Fara til baka",
     "Share folder" : "Deila möppu",
@@ -87,21 +96,16 @@ OC.L10N.register(
     "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-fréttastreymið krefst auðkenningar með Nextcloud-auðkennum þínum",
     "Search" : "Search",
     "Empty trash bin" : "Tæma ruslið",
-    "Sort by created date" : "Sort by created date",
-    "Sort by last modified" : "Raða eftir þegar var síðast breytt",
-    "Sort by title" : "Raða eftir titli",
-    "Sort by click count" : "Raða eftir fjölda smella",
-    "Sort by manual order" : "Raða eftir handvirkri röð",
-    "Sort by URL" : "Raða eftir slóð",
-    "RSS feed copied" : "RSS-fréttastreymi afritað",
     "Enter a link" : "Settu inn slóð",
     "Enter a title" : "Settu inn titil",
     "No bookmarks found" : "Engin bókamerki fundust",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} möppur og {bookmarks} bókamerki",
+    "_%n folder_::_%n folders_" : ["%n mappa","%n möppur"],
     "Welcome to Bookmarks" : "Velkomin í bókamerkin",
     "Add a bookmark" : "Bæta við bókamerki",
     "Import bookmarks" : "Flytja inn bókamerki",
     "Sync with your browser" : "Samstilltu við vafrann þinn",
+    "Do you really want to permanently delete this folder?" : "Viltu eyða þessari möppu endanlega?",
     "Select folder" : "Veldu möppu",
     "Enter folder title" : "Settu inn heiti möppu",
     "Shared by {user}" : "Deilt af {user}",
@@ -110,7 +114,6 @@ OC.L10N.register(
     "Put folder into trashbin" : "Setja möppu í ruslið",
     "Restore folder" : "Endurheimta möppu",
     "Delete folder permanently" : "Eyða möppu endanlega",
-    "Do you really want to permanently delete this folder?" : "Viltu eyða þessari möppu endanlega?",
     "Choose folder" : "Veldu möppu",
     "Submit" : "Senda inn",
     "Cancel" : "Hætta við",
@@ -120,6 +123,9 @@ OC.L10N.register(
     "Moving selection" : "Færi valið",
     "Adding selection to folders" : "Bæti vali í möppur",
     "Emptying trashbin" : "Tæmi ruslið",
+    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
+    "_Moving %n folder_::_Moving %n folders_" : ["Færi %n möppu","Færi %n möppur"],
+    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Færi %n bókamerki","Færi %n bókamerki"],
     "All bookmarks" : "Öll bókamerki",
     "Recent" : "Nýlegt",
     "Shared with you" : "Deilt með þér",
@@ -143,6 +149,9 @@ OC.L10N.register(
     "You haven't deleted anything yet." : "Þú hefur ekki eytt neinu ennþá.",
     "No bookmarks here" : "Engin bókamerki hér",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Bættu við bókamerkjum handvirkt eða flyttu inn bókamerki úr HTML-skrá.",
+    "Archive path" : "Slóð á safn",
+    "Backup path" : "Slóð á öryggisafrit",
+    "Please select \"Add to home screen\" in your browser menu" : "Veldu \"Bæta á upphafsskjá\" í valmynd vafrans þíns",
     "Bookmarks settings" : "Stillingar bókamerkja",
     "Import/Export" : "Inn-/útflutningur",
     "Export bookmarks" : "Flytja út bókamerki",
@@ -166,9 +175,8 @@ OC.L10N.register(
     "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ef þú lendir í vandræðum með bókamerkjaforritið eða hefur hugmyndir um hvernig hægt væri að bæta það, skaltu ekki hika við að hafa samband með því að smella hér.",
     "Support this project" : "Styrkja þetta verkefni",
     "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Vinnan við þetta bókamerkjaforrit er fjármögnuð með valfrjálsu áskriftarlíkani. Ef þér finnst þetta þess virði, væri ánægjulegt ef þú sæir þér fært að styrkja verkefnið. Eins gætirðu íhugað að gefa forritinu umsögn í Nextcloud-forritaversluninni. Takk kærlega 💙 ",
-    "Archive path" : "Slóð á safn",
-    "Backup path" : "Slóð á öryggisafrit",
-    "Please select \"Add to home screen\" in your browser menu" : "Veldu \"Bæta á upphafsskjá\" í valmynd vafrans þíns",
+    "Created {time} ago" : "Búið til fyrir {time} síðan",
+    "Created on {date}" : "Búið til {date}",
     "(Empty title)" : "(auður titill)",
     "Title" : "Titill",
     "Link" : "Tengill",
@@ -181,8 +189,7 @@ OC.L10N.register(
     "Archived file" : "Skrá í safni",
     "Download file" : "Sækja skrá",
     "Open file location" : "Opna staðsetningu skráar",
-    "Created {time} ago" : "Búið til fyrir {time} síðan",
-    "Created on {date}" : "Búið til {date}",
+    "Link copied" : "Tengill afritaður",
     "Owner" : "Eigandi",
     "Sharing" : "Deiling",
     "Select a user or group" : "Veldu notanda eða hóp",
@@ -196,7 +203,8 @@ OC.L10N.register(
     "Allow editing" : "Leyfa breytingar",
     "Allow resharing" : "Leyfa endurdeilingu",
     "Remove share" : "Fjarlægja sameign",
-    "Link copied" : "Tengill afritaður",
+    "Failed to save settings" : "Mistókst að vista stillingar",
+    "Failed to load settings" : "Mistókst að hlaða inn stillingum",
     "Privacy" : "Gagnaleynd",
     "The app will try to access web pages that you add to automatically add information about them." : "Bókamerkjaforritið mun reyna að fá aðgang að þeim síðum sem þú bætir við til að sækja sjálfvirkt upplýsingar um þær.",
     "Enable accessing and collecting information from the web pages you add" : "Virkja aðgang og söfnun upplýsinga af vefsíðunum sem þú bætir við",
@@ -219,8 +227,6 @@ OC.L10N.register(
     "Pageres CLI" : "Pageres CLI",
     "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Settu einfaldlega upp Pageres CLI frá Sindre Sorhus á netþjóninum þínum og bókamerkjaforritið mun finna það. Þú getur eftir sem áður fóðrað fleiri ENV-umhverfisbreytur til pageres, t.d. eins og dæmi er um í frátökutákninu:",
     "Pageres ENV variables" : "Pageres ENV umhverfisbreytur",
-    "Failed to save settings" : "Mistókst að vista stillingar",
-    "Failed to load settings" : "Mistókst að hlaða inn stillingum",
     "This URL is already bookmarked! Overwrite?" : "Þessi slóð er þegar bókamerkt! Skrifa yfir?",
     "Enter bookmark title" : "Settu inn titil á bókamerki",
     "Enter bookmark URL" : "Settu inn slóð á bókamerki",
@@ -241,6 +247,7 @@ OC.L10N.register(
     "Failed to move bookmark" : "Mistókst að færa bókamerki",
     "Failed to copy bookmark" : "Mistókst að afrita bókamerki",
     "Failed to delete bookmark" : "Mistókst að eyða bókamerki",
+    "Import successful" : "Innflutningur tókst",
     "Failed to rename tag" : "Mistókst að endurnefna merki",
     "Failed to load tags" : "Mistókst að hlaða inn merkjum",
     "Failed to load folders" : "Mistókst að hlaða inn möppum",
@@ -249,6 +256,8 @@ OC.L10N.register(
     "Failed to delete folder" : "Mistókst að eyða möppu",
     "Failed to move folder" : "Mistókst að færa möppu",
     "Failed to create folder" : "Mistókst að búa til möppu",
+    "Failed to move parts of selection" : "Mistókst að færa hluta af völdu",
+    "Failed to delete parts of selection" : "Mistókst að eyða hluta af völdu",
     "Failed to fetch bookmarks." : "Ekki tókst að sækja bókamerki.",
     "Failed to store setting" : "Mistókst að geyma stillingu",
     "Failed to load setting {key}" : "Mistókst að hlaða inn {key} stillingunni",
