@@ -1,4 +1,5 @@
 <?php
+
 /*
  * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
@@ -23,7 +24,7 @@ class AdminSettings implements ISettings {
 	public function __construct(
 		private $appName,
 		private SettingsService $settingsService,
-		private IInitialStateService $initialState
+		private IInitialStateService $initialState,
 	) {
 	}
 
